@@ -23,8 +23,8 @@
  * @brief Handle request to interactively edit policy
  * @author Christian Grothoff
  */
-#include <gnunet/platform.h>
 #include <gnunet/gnunet_util_lib.h>
+#include <strings.h>
 #include "anastasis-gtk_action.h"
 #include "anastasis-gtk_helper.h"
 #include "anastasis-gtk_pe.h"
